@@ -23,6 +23,7 @@ class Connector(APIResource):
     credentials = None
     s3_path = None
     s3_client = None
+    s3_resource = None
 
     @classmethod
     def get_credentials(cls, user_token: str = None, renew: bool = False):
@@ -54,6 +55,8 @@ class Connector(APIResource):
         fs = s3fs.S3FileSystem()
         try:
             file_list = fs.ls(cls.get_s3_path(user_token=user_token), refresh=True)
+            # remove first item - path item
+            file_list.pop(0)
         except PermissionError as ex:
             print(' '.join(['folder is empty:', str(ex)]))
         return file_list
@@ -62,10 +65,19 @@ class Connector(APIResource):
     def get_s3_boto_client(cls, user_token: str = None):
         cls.get_credentials(user_token)
         cls.s3_client = boto3.client('s3',
-                                 aws_access_key_id=cls.credentials['access_key'],
-                                 aws_secret_access_key=cls.credentials['secret_key'],
-                                 aws_session_token=cls.credentials['session_token'])
-        return cls.s3_client  # , cls.credentials['bucket'], cls.credentials['path']
+                                     aws_access_key_id=cls.credentials['access_key'],
+                                     aws_secret_access_key=cls.credentials['secret_key'],
+                                     aws_session_token=cls.credentials['session_token'])
+        return cls.s3_client
+
+    @classmethod
+    def get_s3_boto_resource(cls, user_token: str = None):
+        cls.get_credentials(user_token)
+        cls.s3_resource = boto3.resource('s3',
+                                         aws_access_key_id=cls.credentials['access_key'],
+                                         aws_secret_access_key=cls.credentials['secret_key'],
+                                         aws_session_token=cls.credentials['session_token'])
+        return cls.s3_resource
 
     @classmethod
     def read_to_pandas_df(cls, file_name: str, user_token: str = None, **kwargs):
@@ -76,10 +88,7 @@ class Connector(APIResource):
 
     @classmethod
     def write_pandas_df_to_s3(cls, df, file_name: str, user_token: str = None, **kwargs):
-        cls.get_s3_boto_client(user_token=user_token)
+        cls.get_s3_boto_resource(user_token=user_token)
         csv_buffer = StringIO()
         df.to_csv(csv_buffer, **kwargs)
-        cls.s3_client.upload_fileobj(csv_buffer, cls.credentials['bucket'], '/'.join([cls.credentials['path'], file_name]))
-
-
-
+        cls.s3_resource.Object(cls.credentials['bucket'], '/'.join([cls.credentials['path'], file_name])).put(Body=csv_buffer.getvalue())
