@@ -394,8 +394,8 @@ class MyWhatify:
         return my_toolkit.Connector.get_client_path(user_token=user_token)
 
     @classmethod
-    def get_credentials(cls, api_key: str = None):
-        return my_toolkit.Connector.get_credentials(user_token=api_key)
+    def get_credentials(cls, api_key: str = None, renew: bool = False):
+        return my_toolkit.Connector.get_credentials(user_token=api_key, renew=renew)
 
     @classmethod
     def get_s3_path(cls, user_token: str = None):
